# OU Book Theme

The OU Book Theme is an extension of the [Sphinx Book Theme](https://sphinx-book-theme.readthedocs.io), adding Open University specific theming,
as well as custom directives and roles. It is primarily meant for use with [Jupyter Book](https://jupyterbook.org) and all examples assume that use.
